@@ -21,9 +21,9 @@ sub loop_io_remove_all : Export { $SINGLE->io_remove_all(@_); }
 sub loop_io_remove_fd : Export  { $SINGLE->io_remove_fd(@_); }
 
 sub loop_zone : prototype(&) : Export     { $SINGLE->zone(@_) }
-sub loop_zone_cb : prototype(&) : Export  { $SINGLE->zone_cb(@_) }
+sub loop_zone_cb : Export                 { $SINGLE->zone_cb(@_) }
 sub loop_zone_level : Export              { $SINGLE->zone_level(@_) }
-sub loop_zone_escape : Export             { $SINGLE->zone_escape(@_) }
+sub loop_escape_to_level : Export         { $SINGLE->escape_to_level(@_) }
 sub loop_zone_middleware : Export         { $SINGLE->zone_middleware(@_) }
 sub loop_postpone : prototype(&) : Export { $SINGLE->postpone(@_) }
 
@@ -41,7 +41,7 @@ Evo::Loop
 
 =head1 VERSION
 
-version 0.0216
+version 0.0217
 
 =head1 AUTHOR
 
