@@ -1,5 +1,5 @@
 package Evo::Loop::Class;
-use Evo -Class, '-Lib steady_time; List::Util first; Time::HiRes usleep';
+use Evo -Class, '-Lib steady_time; List::Util first; Time::HiRes usleep; Carp croak';
 
 # pay attention. One for all and limited (but big enough)
 my $UID = 0;
@@ -51,6 +51,18 @@ sub start($self) {
   $self->maybe_sleep while $self->tick && $self->is_running;
 }
 
+
+# postpone callback with a previous level
+sub escape_to_level ($self, $level, $cb) : Public {
+  my $data = $self->zone_data;
+  croak "Bad level $level (max ${\$self->zone_level})" unless $level < $self->zone_level;
+  push $self->postpone_queue->@*, sub {
+    local $data->{middleware} = [map { [$_->@*] } @{$data->{middleware}}[0 .. $level]];
+    $cb->();
+  };
+}
+
+
 1;
 
 __END__
@@ -65,7 +77,7 @@ Evo::Loop::Class
 
 =head1 VERSION
 
-version 0.0216
+version 0.0217
 
 =head1 AUTHOR
 
